@@ -15,7 +15,8 @@ sub get_optimal_bufsize {
     my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
         $atime,$mtime,$ctime,$blksize,$blocks)
         = stat $fh;
-    if ((defined $blksize ) && ($blksize >= 512)) {
+    # Windows systems return "" for $blksize
+    if ((defined $blksize ) && ($blksize ne "") && ($blksize >= 512)) {
         return $blksize;
     }
     return 8192;
@@ -54,7 +55,7 @@ Archive::BagIt::Role::Algorithm - A role that defines the interface to a hashing
 
 =head1 VERSION
 
-version 0.068
+version 0.069
 
 =head1 AVAILABILITY
 
